@@ -4,12 +4,12 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Carp                ();
-use File::Find          ();
 use Perl::PrereqScanner ();
 use Test::Builder       ();
+use Test::XTFiles       ();
 use version 0.77 ();
 
 my $TEST = Test::Builder->new();
@@ -22,55 +22,11 @@ my $TEST = Test::Builder->new();
 #   Test::Builder::Tester because TBT cannot test them.
 
 sub all_files_ok {
-    my $self = shift;
-
-    my @args = scalar @_ ? @_ : $self->_default_dirs();
-    if ( !@args ) {
-        $TEST->skip_all("No files found\n");
-        return 1;
-    }
-
-    my @files;
-  ARG:
-    for my $arg (@args) {
-        if ( !-e $arg ) {
-            $TEST->carp("File '$arg' does not exist");
-            next ARG;
-        }
-
-        if ( -l $arg ) {
-            $TEST->carp("Ignoring symlink '$arg'");
-            next ARG;
-        }
-
-        if ( -f $arg ) {
-            push @files, $arg;
-            next ARG;
-        }
-
-        if ( !-d $arg ) {
-            $TEST->carp("File '$arg' is not a file nor a directory. Ignoring it.");
-            next ARG;
-        }
-
-        File::Find::find(
-            {
-                no_chdir   => 1,
-                preprocess => sub {
-                    my @sorted = sort grep { !-l "$File::Find::dir/$_" } @_;
-                    return @sorted;
-                },
-                wanted => sub {
-                    return if !-f $File::Find::name;
-                    push @files, $File::Find::name;
-                },
-            },
-            $arg,
-        );
-    }
+    my ($self) = @_;
 
+    my @files = Test::XTFiles->new->all_perl_files();
     if ( !@files ) {
-        $TEST->skip_all("No files found in (@args)\n");
+        $TEST->skip_all("No files found\n");
         return 1;
     }
 
@@ -173,29 +129,6 @@ sub file_ok {
     return;
 }
 
-sub _default_dirs {
-    my ($self) = @_;
-
-    my @dirs;
-    if ( -d 'blib' ) {
-        push @dirs, 'blib';
-    }
-    elsif ( -d 'lib' ) {
-        push @dirs, 'lib';
-    }
-
-    if ( -d 'bin' ) {
-        push @dirs, 'bin';
-    }
-
-    if ( -d 'script' ) {
-        push @dirs, 'script';
-    }
-
-    my @sorted = sort @dirs;
-    return @sorted;
-}
-
 1;
 
 __END__
@@ -206,11 +139,11 @@ __END__
 
 =head1 NAME
 
-Test::RequiredMinimumDependencyVersion - Require a minimum version for your dependencies
+Test::RequiredMinimumDependencyVersion - require a minimum version for your dependencies
 
 =head1 VERSION
 
-Version 0.002
+Version 0.003
 
 =head1 SYNOPSIS
 
@@ -262,20 +195,23 @@ instead of a C<plan>.
 C<file_ok> returns something I<true> if all checked dependencies are at least
 of the required minimal version and I<false> otherwise.
 
-=head2 all_files_ok( [ @entries ] )
+=head2 all_files_ok
 
-Checks all the files under C<@entries> by calling C<file_ok> on every
-file. Directories are recursive searched for files. Everything not a file and
-not a directory (e.g. a symlink) is ignored. It calls C<done_testing> or
-C<skip_all> so you can't have already called C<plan>.
+Calls the C<all_perl_files> method of L<Test::XTFiles> to get all the files to
+be tested. All files will be checked by calling C<file_ok>.
 
-If C<@entries> is empty default directories are searched for files.
-The default directories are F<blib>, or F<lib> if it doesn't
-exist, F<bin> and F<script>.
+It calls C<done_testing> or C<skip_all> so you can't have already called
+C<plan>.
 
 C<all_files_ok> returns something I<true> if all files test ok and I<false>
 otherwise.
 
+Please see L<XT::Files> for how to configure the files to be checked.
+
+WARNING: The API was changed with 0.003. Arguments to C<all_files_ok>
+are now silently discarded and the method is now configured with
+L<XT::Files>.
+
 =head1 EXAMPLES
 
 =head2 Example 1 Default Usage
@@ -296,18 +232,16 @@ Check all files in the F<bin>, F<script> and F<lib> directory.
 
 =head2 Example 2 Check non-default directories or files
 
-    use 5.006;
-    use strict;
-    use warnings;
+Use the same test file as in Example 1 and create a F<.xtfilesrc> config
+file in the root directory of your distribution.
 
-    use Test::RequiredMinimumDependencyVersion;
+    [Dirs]
+    module = lib
+    module = tools
+    module = corpus/hello
 
-    Test::RequiredMinimumDependencyVersion->new(
-        module => {
-            'Test::More' => '0.88',
-            'version'    => '0.77',
-        },
-    )->all_files_ok(qw(bin lib t xt corpus/hello_world.pl));
+    [Files]
+    module = corpus/my.pm
 
 =head2 Example 3 Call C<file_ok> directly
 
@@ -355,7 +289,7 @@ Sven Kirmess <sven.kirmess@kzone.ch>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Sven Kirmess.
+This software is Copyright (c) 2018-2019 by Sven Kirmess.
 
 This is free software, licensed under:
 
